### Name: spec.ar
### Title: Estimate Spectral Density of a Time Series from AR Fit
### Aliases: spec.ar
### Keywords: ts

### ** Examples

spec.ar(lh)

spec.ar(ldeaths)
spec.ar(ldeaths, method="burg")



